@@ -2,7 +2,7 @@ library(bayesTFR)
 source('test_functions.R')
 
 cran <- TRUE
-for(wpp in c(2010, 2012, 2015, 2017)) {
+for(wpp in rev(c(2010, 2012, 2015, 2017, 2019))) {
 	test.load.UNtfr(wpp)
 	test.load.UNlocations(wpp)
 	test.create.tfr.matrix(wpp)
@@ -29,4 +29,5 @@ if(!cran) {
 	test.run.mcmc.simulation.auto()
 	test.run.mcmc.simulation.auto.parallel()
 	test.plot.all()
+	test.reproduce.simulation()
 }
\ No newline at end of file
